==> GNOWSYS-0.3.tgz: GNOWSYS/CF/OldShowAssociation.py <==
import string

#PATH = string.replace(context.surl,'http://hbcse.tifr.res.in:9673','')
#print PATH

#PATH = '/' + context.getPhysicalPath()[1]
PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')
request = container.REQUEST
AssociationType = request['AssociationType']

PATH1 = PATH + '/Data/AssociationTypes/' + AssociationType[0]
AssocTypeRef = context.restrictedTraverse(PATH1)

a = AssocTypeRef.getProperty('LRoles')
b = AssocTypeRef.getProperty('RRoles')

Robjs=[]
Lobjs=[]

for x in context.Data.Objects.objectIds():
     PATH2 = PATH + '/Data/Objects/' + x
     ObjRef = context.restrictedTraverse(PATH2)
     if a[0] in ObjRef.getProperty('ObjectTypes'):
            Lobjs.append(ObjRef.getProperty('BaseName'))
     if b[0] in ObjRef.getProperty('ObjectTypes'):
            Robjs.append(ObjRef.getProperty('BaseName'))

#print context.standard_html_header

print '<H2> Add Association </H2>'
print '<form action=manage_addnewAssoc method=post>'

#AT = str(AssociationType[0])

AT = string.replace(str(AssociationType[0]),' ','_')

print '<dtml-var standard_html_header>'
print '<table>'
print '<tr><td> <input type=hidden name=AssType:tokens value=',AT,'></td></tr>'
print '<tr> <td align=left><strong>Left Objects</strong></td><td></td>'
print '<td align=left><strong>Right Objects</strong></td> </tr>'
print '<tr> <td><select class=form-element name=LObjects:list>'
for i in Lobjs:
        print '<option>',i,'</option>'
print '<td align=left><strong>',AssociationType[0],'</strong></td>'
print ' </select> </td>'
print '<td><select class=form-element name=RObjects:list>'
for i in Robjs:
        print '<option>',i,'</option>'
print ' </select> </td> </tr>'
print '<tr><td></td></tr>'
print '<tr><td></td></tr>'
print '<tr><td></td></tr>'
print '<tr><td></td><td align=center>'
print '<input type=submit value=Submit>'
print '</td></tr></table></form>'

bk = context.surl+'/bkbdocadd'

print '<center>'
print '<form action=',bk,' method=post>'
print '<table> <tr> <td align=left>'
print '<input type=submit value=Back>'
print '</td></tr></table></form>'

print '</center>'
print '<dtml-var standard_html_footer>'
#print context.standard_html_footer

return printed

==> GNOWSYS-0.4-r0.tgz: GNOWSYS/CF/OldShowAssociation.py <==
import string

#PATH = string.replace(context.surl,'http://hbcse.tifr.res.in:9673','')
#print PATH

#PATH = '/' + context.getPhysicalPath()[1]
#PATH = string.replace( context.surl, container.REQUEST['BASE0'], '')

request = container.REQUEST
AssociationType = request['AssociationType']

PATH = context.getInstancePath()
PATH1 = PATH + '/Data/AssociationTypes/' + AssociationType[0]
AssocTypeRef = context.restrictedTraverse(PATH1)

a = AssocTypeRef.getProperty('LRoles')
b = AssocTypeRef.getProperty('RRoles')

Robjs=[]
Lobjs=[]

for x in context.Data.Objects.objectIds():
     PATH2 = PATH + '/Data/Objects/' + x
     ObjRef = context.restrictedTraverse(PATH2)
     if a[0] in ObjRef.getProperty('ObjectTypes'):
            Lobjs.append(ObjRef.getProperty('BaseName'))
     if b[0] in ObjRef.getProperty('ObjectTypes'):
            Robjs.append(ObjRef.getProperty('BaseName'))

#print context.standard_html_header

print '<H2> Add Association </H2>'
print '<form action=manage_addnewAssoc method=post>'

#AT = str(AssociationType[0])

AT = string.replace(str(AssociationType[0]),' ','_')

print '<dtml-var standard_html_header>'
print '<table>'
print '<tr><td> <input type=hidden name=AssType:tokens value=',AT,'></td></tr>'
print '<tr> <td align=left><strong>Left Objects</strong></td><td></td>'
print '<td align=left><strong>Right Objects</strong></td> </tr>'
print '<tr> <td><select class=form-element name=LObjects:list>'
for i in Lobjs:
        print '<option>',i,'</option>'
print '<td align=left><strong>',AssociationType[0],'</strong></td>'
print ' </select> </td>'
print '<td><select class=form-element name=RObjects:list>'
for i in Robjs:
        print '<option>',i,'</option>'
print ' </select> </td> </tr>'
print '<tr><td></td></tr>'
print '<tr><td></td></tr>'
print '<tr><td></td></tr>'
print '<tr><td></td><td align=center>'
print '<input type=submit value=Submit>'
print '</td></tr></table></form>'

bk = context.surl+'/bkbdocadd'

print '<center>'
print '<form action=',bk,' method=post>'
print '<table> <tr> <td align=left>'
print '<input type=submit value=Back>'
print '</td></tr></table></form>'

print '</center>'
print '<dtml-var standard_html_footer>'
#print context.standard_html_footer

return printed
